@@ -40,13 +40,18 @@ VERSION_1 = '1.0.0'
 VERSION_1_1 = '1.1.0'
 VERSION_1_2 = '1.2.0'
 VERSION_2_0 = '2.0.0'
-VERSION_3_0 = '3.0.7'
+VERSION_3_0 = '3.0.10'
 
 # For a new release, define a new constant and assign it to LAST_VERSION
 # The existing one has to be added to OLD_VERSIONS list.
 LAST_VERSION = VERSION_3_0
 OLD_VERSIONS = (VERSION_1, VERSION_1_1, VERSION_1_2, VERSION_2_0)
 
+# STATUS
+PROD = 0
+BETA = 1
+NEW = 2
+
 # Dir names
 APPS = 'apps'
 DATA_TAG = 'data'
@@ -63,6 +68,7 @@ SCIPION_PYTHON = 'SCIPION_PYTHON'
 SCIPION_PYTHON_DEFAULT = 'python3'
 SCIPION_HOME_VAR = 'SCIPION_HOME'
 SCIPION_TESTS = 'SCIPION_TESTS'
+SCIPION_SCRATCH = 'SCIPION_SCRATCH'
 
 # NOTES CONSTANTS
 SCIPION_NOTES_FILE = 'SCIPION_NOTES_FILE'
@@ -100,3 +106,11 @@ TK_GRAY_DEFAULT = '#d9d9d9'
 SCIPION_TESTS_CMD = 'SCIPION_TESTS_CMD'
 CONDA_ACTIVATION_CMD_VAR = 'CONDA_ACTIVATION_CMD'
 VIEWERS = 'VIEWERS'
+
+
+class DOCSITEURLS:
+    """Documentation site URL usefull when exceptions happens and you want to point to some pages"""
+    HOME = 'https://scipion-em.github.io/docs/'
+    CONFIG = HOME + 'docs/scipion-modes/scipion-configuration.html'
+    CONFIG_SECTION = CONFIG + '#%s'
+    CONTACTUS = 'http://scipion.i2pc.es/contact'
