@@ -6,7 +6,7 @@
 # *
 # * This program is free software; you can redistribute it and/or modify
 # * it under the terms of the GNU General Public License as published by
-# * the Free Software Foundation; either version 2 of the License, or
+# * the Free Software Foundation; either version 3 of the License, or
 # * (at your option) any later version.
 # *
 # * This program is distributed in the hope that it will be useful,
@@ -47,25 +47,25 @@ class Canvas(tk.Canvas, Scrollable):
     """Canvas to draw some objects.
     It will really contains a Frame, a Canvas and scrollbars"""
     _images = {}
-    
+
     def __init__(self, parent, tooltipCallback=None, tooltipDelay=1500, **kwargs):
         defaults = {'bg': 'white'}
         defaults.update(kwargs)
         Scrollable.__init__(self, parent, tk.Canvas, **defaults)
-        
+
         self.lastItem = None  # Track last item selected
         self.lastPos = (0, 0)  # Track last clicked position
         self.eventPos = (0, 0)
         self.firstPos = None  # Track first clicked position (for a drag action)
         self.items = {}  # Keep a dictionary with high-level items
         self.cleanSelected = True
-        
+
         self.onClickCallback = None
         self.onDoubleClickCallback = None
         self.onRightClickCallback = None
         self.onControlClickCallback = None
         self.onAreaSelected = None
-        
+
         # Add bindings
         self.bind("<Button-1>", self.onClick)
         self.bind("<ButtonRelease-1>", self.onButton1Release)
@@ -81,7 +81,7 @@ class Canvas(tk.Canvas, Scrollable):
         # Scroll bindings in Linux
         self.bind("<Shift-Button-4>", self.zoomerP)
         self.bind("<Shift-Button-5>", self.zoomerM)
-        
+
         self._tooltipId = None
         self._tooltipOn = False  # True if the tooltip is displayed
         self._tooltipCallback = tooltipCallback
@@ -89,14 +89,14 @@ class Canvas(tk.Canvas, Scrollable):
 
         self._runsFont = getDefaultFont().copy()
         self._zoomFactor = DEFAULT_ZOOM
-        
+
         if tooltipCallback:
             self.bind('<Motion>', self.onMotion)
             # self.bind('<Leave>', self.onLeave)
             self._createTooltip()  # This should set
-        
+
         self._menu = tk.Menu(self, tearoff=0)
-        
+
     def _createTooltip(self):
         """ Create a Tooltip window to display tooltips in 
         the canvas.
@@ -105,9 +105,9 @@ class Canvas(tk.Canvas, Scrollable):
         tw.withdraw()  # hidden by default
         tw.wm_overrideredirect(1)  # Remove window decorations
         tw.bind("<Leave>", self.hideTooltip)
-        
+
         self._tooltip = tw
-        
+
     def _showTooltip(self, x, y, item):
         # check that the mouse is still in the position
         nx = self.winfo_pointerx()
@@ -119,7 +119,7 @@ class Canvas(tk.Canvas, Scrollable):
             tw.update_idletasks()
             tw.wm_geometry("+%d+%d" % (x, y))
             tw.deiconify()
-        
+
     def hideTooltip(self, e=None):
         if self._tooltipOn:
             self._tooltipOn = False
@@ -131,17 +131,17 @@ class Canvas(tk.Canvas, Scrollable):
 
     def getImage(self, img):
         return gui.getImage(img, self._images)
-    
+
     def _unpostMenu(self, e=None):
         self._menu.unpost()
-      
+
     def getCoordinates(self, event):
         """Converts the events coordinates to canvas coordinates"""
         # Convert screen coordinates to canvas coordinates
         xc = self.canvasx(event.x)
         yc = self.canvasy(event.y)
         return xc, yc
-    
+
     def selectItem(self, item):
         if self.lastItem:
             self.lastItem.setSelected(False)
@@ -167,12 +167,12 @@ class Canvas(tk.Canvas, Scrollable):
         in the mouse event coordinates.
         Return None if not Found
         """
-        items = self.find_overlapping(xc-1, yc-1,  xc+1, yc+1)
+        items = self.find_overlapping(xc - 1, yc - 1, xc + 1, yc + 1)
         for i in items:
             if i in self.items:
                 return self.items[i]
         return None
-             
+
     def _handleMouseEvent(self, event, callback):
         # Store last event coordinates
         self.eventPos = (event.x, event.y)
@@ -198,7 +198,7 @@ class Canvas(tk.Canvas, Scrollable):
         self.cleanSelected = False
         self._unpostMenu()
         self._handleMouseEvent(event, self.onControlClickCallback)
-            
+
     def onRightClick(self, e=None):
         # RightClick callback will not work not, as it need
         # the event information to know the coordinates
@@ -207,24 +207,24 @@ class Canvas(tk.Canvas, Scrollable):
         # If the callback return a list of actions
         # we will show up a menu with them
         actions = self.callbackResults
-        
+
         if actions:
             self._menu.delete(0, tk.END)
             for a in actions:
-                if a is None: 
+                if a is None:
                     self._menu.add_separator()
                 else:
                     img = ''
                     if len(a) > 2:  # image for the action
                         img = self.getImage(a[2])
-                    self._menu.add_command(label=a[0], command=a[1], 
+                    self._menu.add_command(label=a[0], command=a[1],
                                            image=img, compound=tk.LEFT,
-                                           font = gui.getDefaultFont())
+                                           font=gui.getDefaultFont())
             self._menu.post(e.x_root, e.y_root)
             unpost = False
         if unpost:
             self._menu.unpost()
-    
+
     def onDoubleClick(self, event):
         self._handleMouseEvent(event, self.onDoubleClickCallback)
 
@@ -240,7 +240,7 @@ class Canvas(tk.Canvas, Scrollable):
 
             if self.lastItem:
                 xc, yc = self.getCoordinates(event)
-                self.lastItem.move(xc-self.lastPos[0], yc-self.lastPos[1])
+                self.lastItem.move(xc - self.lastPos[0], yc - self.lastPos[1])
                 self.lastPos = (xc, yc)
             else:
                 if self.firstPos is None:
@@ -266,20 +266,20 @@ class Canvas(tk.Canvas, Scrollable):
 
     def onMotion(self, event):
         self.onLeave(event)  # Hide tooltip and cancel schedule
-            
+
         xc, yc = self.getCoordinates(event)
         item = self._findItem(xc, yc)
         if item is not None:
-            self._tooltipId = self.after(self._tooltipDelay, 
+            self._tooltipId = self.after(self._tooltipDelay,
                                          lambda: self._showTooltip(event.x_root,
                                                                    event.y_root,
-                                                                   item))  
-        
+                                                                   item))
+
     def onLeave(self, event):
         if self._tooltipId:
             self.after_cancel(self._tooltipId)
             self.hideTooltip()
-            
+
     def createTextbox(self, text, x, y, bgColor="#99DAE8", textColor='black'):
         tb = TextBox(self, text, x, y, bgColor, textColor)
         self.items[tb.id] = tb
@@ -294,15 +294,15 @@ class Canvas(tk.Canvas, Scrollable):
         tb = RoundedTextBox(self, text, x, y, bgColor, textColor)
         self.items[tb.id] = tb
         return tb
-    
+
     def addItem(self, item):
         self.items[item.id] = item
-    
+
     def createEdge(self, srcItem, dstItem):
         edge = Edge(self, srcItem, dstItem)
         # self.items[edge.id] = edge
         return edge
-    
+
     def createCable(self, src, srcSocket, dst, dstSocket):
         return Cable(self, src, srcSocket, dst, dstSocket)
 
@@ -314,7 +314,7 @@ class Canvas(tk.Canvas, Scrollable):
     def updateScrollRegion(self):
         self.update_idletasks()
         self.config(scrollregion=self.bbox("all"))
-        
+
     # linux zoom
     def __zoom(self, event, scale):
 
@@ -329,12 +329,12 @@ class Canvas(tk.Canvas, Scrollable):
         self.scale("all", 0, 0, scale, scale)
         self.__scaleFonts()
         self.configure(scrollregion=self.bbox("all"))
-        
+
     def __scaleFonts(self):
 
         currentFontSize = self._runsFont['size']
         newFontSize = currentFontSize
-        
+
         zoomPairs = [(32, 7),
                      (44, 6),
                      (53, 5),
@@ -358,10 +358,10 @@ class Canvas(tk.Canvas, Scrollable):
 
     def zoomerP(self, event):
         self.__zoom(event, 1.111111)
-        
+
     def zoomerM(self, event):
         self.__zoom(event, 0.9)
-        
+
     def drawGraph(self, graph, layout=None, drawNode=None):
         """ Draw a graph in the canvas.
         nodes in the graph should have x and y.
@@ -380,25 +380,25 @@ class Canvas(tk.Canvas, Scrollable):
             self.drawNode = self._drawNode
         else:
             self.drawNode = drawNode
-        
+
         self._drawNodes(graph.getRoot(), {})
-        
+
         if layout is not None:
             layout.draw(graph)
-            
+
         # Update node positions
         self._updatePositions(graph.getRoot(), {})
         self.updateScrollRegion()
         self.__zoom(None, scale)
-        
+
     def _drawNode(self, canvas, node):
         """ Default implementation to draw nodes as textboxes. """
         return TextBox(self, node.getLabel(), 0, 0,
                        bgColor="#99DAE8", textColor='black')
-        
+
     def _drawNodes(self, node, visitedDict={}):
         nodeName = node.getName()
-        
+
         if nodeName not in visitedDict:
             visitedDict[nodeName] = True
             item = self.drawNode(self, node)
@@ -412,7 +412,7 @@ class Canvas(tk.Canvas, Scrollable):
                     self._drawNodes(child, visitedDict)
             else:
                 self._setupParentProperties(node, visitedDict)
-                
+
     def _setupParentProperties(self, node, visitedDict):
         """ This methods is used for collapsed nodes, in which 
         the properties (width, height, x and y) is propagated
@@ -425,16 +425,16 @@ class Canvas(tk.Canvas, Scrollable):
                 child.x = node.x
                 child.y = node.y
                 self._setupParentProperties(child, visitedDict)
-        
+
     def _updatePositions(self, node, visitedDict={}):
         """ Update position of nodes and create the edges. """
         nodeName = node.getName()
-        
+
         if nodeName not in visitedDict:
             visitedDict[nodeName] = True
             item = node.item
             item.moveTo(node.x, node.y)
-            
+
             if getattr(node, 'expanded', True):
                 for child in node.getChilds():
                     self.createEdge(item, child.item)
@@ -548,7 +548,7 @@ class Item(object):
             return [(xc, y1), (xc, y2)]
         return None
 
-    def getCorners(self): 
+    def getCorners(self):
         return self.canvas.bbox(self.id)
 
     def countSockets(self, verticalLocation):
@@ -584,7 +584,7 @@ class Item(object):
     def getSocketCoordsAt(self, verticalLocation, position=1, socketsCount=1):
         x1, y1, x2, y2 = self.getCorners()
         xc = (x2 + x1) / 2.0
-        socketsGroupSize = (socketsCount-1) * self.socketSeparation
+        socketsGroupSize = (socketsCount - 1) * self.socketSeparation
         socketsGroupStart = xc - (socketsGroupSize / 2)
         x = socketsGroupStart + (position - 1) * self.socketSeparation
         if verticalLocation == "top":
@@ -611,7 +611,7 @@ class Item(object):
     def getDimensions(self):
         x, y, x2, y2 = self.canvas.bbox(self.id)
         return x2 - x, y2 - y
-        
+
     def move(self, dx, dy):
         if hasattr(self, "id"):
             self.canvas.move(self.id, dx, dy)
@@ -622,11 +622,11 @@ class Item(object):
             socket["object"].move(dx, dy)
         for listenerFunc in self.listeners:
             listenerFunc(dx, dy)
-            
+
     def moveTo(self, x, y):
         """Move TextBox to a new position (x,y)"""
         self.move(x - self.x, y - self.y)
-        
+
     def addPositionListener(self, listenerFunc):
         self.listeners.append(listenerFunc)
 
@@ -659,6 +659,7 @@ class Item(object):
 class TextItem(Item):
     """This class will serve to paint and store rectangle boxes with some text.
        x and y are the coordinates of the center of this item"""
+
     def __init__(self, canvas, text, x, y, bgColor, textColor='black'):
         super(TextItem, self).__init__(canvas, x, y)
         self.bgColor = bgColor
@@ -666,7 +667,7 @@ class TextItem(Item):
         self.text = text
         self.margin = 8
         self.paint()
-        
+
     def _paintBounds(self, x, y, w, h, fillColor):
         """ Subclasses should implement this method 
         to paint the bounds to the text.
@@ -679,7 +680,7 @@ class TextItem(Item):
             should return the id of the created shape
         """
         pass
-        
+
     def paint(self):
         """Paint the object in a specific position."""
 
@@ -690,7 +691,7 @@ class TextItem(Item):
         xr, yr, w, h = self.canvas.bbox(self.id_text)
         m = self.margin
 
-        self.id = self._paintBounds(xr-m, yr-m, w+m, h+m, fillColor=self.bgColor)
+        self.id = self._paintBounds(xr - m, yr - m, w + m, h + m, fillColor=self.bgColor)
         self.canvas.lift(self.id_text)
 
     def move(self, dx, dy):
@@ -700,8 +701,8 @@ class TextItem(Item):
     def lift(self):
         super(TextItem, self).lift()
         self.canvas.lift(self.id_text)
-   
-        
+
+
 class TextBox(TextItem):
     def __init__(self, canvas, text, x, y, bgColor, textColor='black'):
         super(TextBox, self).__init__(canvas, text, x, y, bgColor, textColor)
@@ -717,28 +718,28 @@ class RoundedTextBox(TextItem):
     def _paintBounds(self, upperLeftX, upperLeftY, bottomRightX, bottomRightY, fillColor):
         d = 5
         # When smooth=1, you define a straight segment by including its ends twice
-        return self.canvas.create_polygon(upperLeftX+d+1, upperLeftY,  # 1
-                                          upperLeftX+d, upperLeftY,  # 1
-                                          bottomRightX-d, upperLeftY,  # 2
-                                          bottomRightX-d, upperLeftY,  # 2
+        return self.canvas.create_polygon(upperLeftX + d + 1, upperLeftY,  # 1
+                                          upperLeftX + d, upperLeftY,  # 1
+                                          bottomRightX - d, upperLeftY,  # 2
+                                          bottomRightX - d, upperLeftY,  # 2
                                           # bottomRightX-d+1,upperLeftY, #2b
-                                          bottomRightX, upperLeftY+d-1,  # 3b
-                                          bottomRightX, upperLeftY+d,  # 3
-                                          bottomRightX, upperLeftY+d,  # 3
-                                          bottomRightX, bottomRightY-d,  # 4
-                                          bottomRightX, bottomRightY-d,  # 4
-                                          bottomRightX-d, bottomRightY,  # 5
-                                          bottomRightX-d, bottomRightY,  # 5
-                                          upperLeftX+d, bottomRightY,  # 6
-                                          upperLeftX+d, bottomRightY,  # 6
+                                          bottomRightX, upperLeftY + d - 1,  # 3b
+                                          bottomRightX, upperLeftY + d,  # 3
+                                          bottomRightX, upperLeftY + d,  # 3
+                                          bottomRightX, bottomRightY - d,  # 4
+                                          bottomRightX, bottomRightY - d,  # 4
+                                          bottomRightX - d, bottomRightY,  # 5
+                                          bottomRightX - d, bottomRightY,  # 5
+                                          upperLeftX + d, bottomRightY,  # 6
+                                          upperLeftX + d, bottomRightY,  # 6
                                           # upperLeftX+d-1,bottomRightY, #6b
-                                          upperLeftX, bottomRightY-d+1,  # 7b
-                                          upperLeftX, bottomRightY-d,  # 7
-                                          upperLeftX, bottomRightY-d,  # 7
-                                          upperLeftX, upperLeftY+d,  # 8
-                                          upperLeftX, upperLeftY+d,  # 8
+                                          upperLeftX, bottomRightY - d + 1,  # 7b
+                                          upperLeftX, bottomRightY - d,  # 7
+                                          upperLeftX, bottomRightY - d,  # 7
+                                          upperLeftX, upperLeftY + d,  # 8
+                                          upperLeftX, upperLeftY + d,  # 8
                                           # upperLeftX, upperLeftY+d-1, #8b
-                                          upperLeftX+d-1, upperLeftY,  # 1b
+                                          upperLeftX + d - 1, upperLeftY,  # 1b
                                           fill=fillColor, outline='black', smooth=1)
 
     def getDimensions(self):
@@ -751,7 +752,8 @@ class TextCircle(TextItem):
 
     def _paintBounds(self, x, y, w, h, fillColor):
         return self.canvas.create_oval(x, y, w, h, fill=fillColor)
-    
+
+
 # This are not used and depends on xmippLib
 # class ImageBox(Item):
 #     def __init__(self, canvas, imgPath, x=0, y=0, text=None):
@@ -782,6 +784,7 @@ class TextCircle(TextItem):
 
 class Connector(Item):
     """ Default connector has no graphical representation (hence, it'ss invisible). Subclasses offer different looks"""
+
     def __init__(self, canvas, x, y, name):
         super(Connector, self).__init__(canvas, x, y)
         self.name = name
@@ -814,17 +817,17 @@ class RoundConnector(ColoredConnector):
     radius = 3
 
     def paintSocket(self):
-        self.socketId = self.canvas.create_oval(self.x-self.radius,
-                                                self.y-self.radius,
-                                                self.x+self.radius,
-                                                self.y+self.radius,
+        self.socketId = self.canvas.create_oval(self.x - self.radius,
+                                                self.y - self.radius,
+                                                self.x + self.radius,
+                                                self.y + self.radius,
                                                 outline=self.outline)
 
     def paintPlug(self):
-        self.plugId = self.canvas.create_oval(self.x-self.radius,
-                                              self.y-self.radius,
-                                              self.x+self.radius,
-                                              self.y+self.radius,
+        self.plugId = self.canvas.create_oval(self.x - self.radius,
+                                              self.y - self.radius,
+                                              self.x + self.radius,
+                                              self.y + self.radius,
                                               fill=self.fillColor, width=0)
 
 
@@ -832,23 +835,24 @@ class SquareConnector(ColoredConnector):
     halfside = 3
 
     def paintSocket(self):
-        self.socketId = self.canvas.create_rectangle(self.x-self.halfside,
-                                                     self.y-self.halfside,
-                                                     self.x+self.halfside,
-                                                     self.y+self.halfside,
+        self.socketId = self.canvas.create_rectangle(self.x - self.halfside,
+                                                     self.y - self.halfside,
+                                                     self.x + self.halfside,
+                                                     self.y + self.halfside,
                                                      outline=self.outline)
 
     def paintPlug(self):
-        self.plugId = self.canvas.create_rectangle(self.x-self.halfside,
-                                                   self.y-self.halfside,
-                                                   self.x+self.halfside,
-                                                   self.y+self.halfside,
+        self.plugId = self.canvas.create_rectangle(self.x - self.halfside,
+                                                   self.y - self.halfside,
+                                                   self.x + self.halfside,
+                                                   self.y + self.halfside,
                                                    fill=self.fillColor, width=0)
 
 
 # !!!! other figures: half circle, diamond...
 class Oval:
     """Oval or circle"""
+
     def __init__(self, canvas, x, y, radio, color='green', anchor=None):
         self.anchor = anchor
         self.X, self.Y = x, y
@@ -916,6 +920,7 @@ class Rectangle:
 
 class Edge:
     """Edge between two objects"""
+
     def __init__(self, canvas, source, dest):
         self.source = source
         self.dest = dest
@@ -929,14 +934,14 @@ class Edge:
         dest.addSelectionListener(self.updateColor)
         self.id = None
         self.paint()
-        
+
     def paint(self):
         # coords = findClosestConnectors(self.source,self.dest)
         coords = getConnectors(self.source, self.dest)
 
         if coords:
             c1Coords, c2Coords = coords
-    
+
             if self.id:
                 self.canvas.delete(self.id)
 
@@ -953,8 +958,8 @@ class Edge:
                 if self.dest.getSelected() and self.source.getSelected():
                     lineColor = '#000'
                     lineWidth = 2
-    
-            self.id = self.canvas.create_line(c1Coords[0], c1Coords[1], 
+
+            self.id = self.canvas.create_line(c1Coords[0], c1Coords[1],
                                               c2Coords[0], c2Coords[1],
                                               width=lineWidth, fill=lineColor)
             self.canvas.tag_lower(self.id)
@@ -963,7 +968,7 @@ class Edge:
         self.srcX += dx
         self.srcY += dy
         self.paint()
-        
+
     def updateDst(self, dx, dy):
         self.dstX += dx
         self.dstY += dy
@@ -993,16 +998,16 @@ class Cable:
         self.paint()
 
     def srcMoved(self, dx, dy):
-        self.srcX = self.srcX+dx
-        self.srcY = self.srcY+dy
+        self.srcX = self.srcX + dx
+        self.srcY = self.srcY + dy
         self.updateCoords()
 
     def updateCoords(self):
         self.canvas.coords(self.id, self.srcX, self.srcY, self.dstX, self.dstY)
 
     def dstMoved(self, dx, dy):
-        self.dstX = self.dstX+dx
-        self.dstY = self.dstY+dy
+        self.dstX = self.dstX + dx
+        self.dstY = self.dstY + dy
         self.updateCoords()
 
     def paint(self):
@@ -1010,20 +1015,21 @@ class Cable:
                                           self.dstY, width=2)
         self.canvas.tag_lower(self.id)
         self.paintPlugs()
-        
+
     def paintPlugs(self):
         self.srcPlug.paintPlug()
         self.dstPlug.paintPlug()
 
- 
+
 if __name__ == '__main__':
     root = tk.Tk()
     canvas = Canvas(root, width=800, height=600)
     canvas.frame.grid(row=0, column=0, sticky='nsew')
     root.grid_columnconfigure(0, weight=1)
     root.grid_rowconfigure(0, weight=1)
-    
-    def canvasExample1():    
+
+
+    def canvasExample1():
         tb1 = canvas.createTextCircle("Project", 100, 100, "blue")
         tb2 = canvas.createTextbox("This is an intentionally quite big, big box,"
                                    "\nas you may appreciate looking carefully"
@@ -1031,7 +1037,7 @@ if __name__ == '__main__':
         tb2.addSocket("output1", RoundConnector, "bottom", fillColor="green")
         tb2.addSocket("output2", SquareConnector, "bottom", fillColor="yellow")
         tb2.addSocket("output3", SquareConnector, "bottom", fillColor="blue")
-        tb3 = canvas.createRoundedTextbox("otro mas\n", 100, 200, "red")
+        tb3 = canvas.createRoundedTextbox("another one\n", 100, 200, "red")
         tb4 = canvas.createRoundedTextbox("tb4", 300, 300, "yellow")
         tb4.addSocket("input1", SquareConnector, "top", outline="red")
         tb5 = canvas.createTextCircle("tb5", 400, 300, "grey")
@@ -1042,7 +1048,7 @@ if __name__ == '__main__':
         c2 = canvas.createCable(tb2, "output3", tb5, "input1")
         tb3.moveTo(100, 300)
 
-       
+
     canvasExample1()
 
     root.mainloop()
